package com.rjconsultores.ventaboletos.relatorios.impl;

import java.sql.Connection;
import java.sql.ResultSet;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import net.sf.jasperreports.engine.data.JRBeanCollectionDataSource;

import com.rjconsultores.ventaboletos.relatorios.utilitarios.DataSource;
import com.rjconsultores.ventaboletos.relatorios.utilitarios.Relatorio;
import com.rjconsultores.ventaboletos.relatorios.utilitarios.RelatorioEmpresaOnibusBean;
import com.rjconsultores.ventaboletos.web.utilerias.NamedParameterStatement;

public class RelatorioEmpresaOnibus extends Relatorio {

	private List<RelatorioEmpresaOnibusBean> lsDadosRelatorio;
	
	public RelatorioEmpresaOnibus(Map<String, Object> parametros, Connection conexao)  throws Exception {
		super(parametros, conexao);
		
		this.setCustomDataSource(new DataSource(this) {
			@Override
			public void initDados() throws Exception {

				Connection conexao = this.relatorio.getConexao();

				Map<String, Object> parametros = this.relatorio.getParametros();

				String fecInicio = parametros.get("fecInicio").toString() + " 00:00:00";
				String fecFinal = parametros.get("fecFinal").toString() + " 23:59:59";
				String empresa = parametros.get("empresa") != null ? parametros.get("empresa").toString() : "";
				String autobus = parametros.get("autobus") != null ? parametros.get("autobus").toString() : "";
				
				String sql = getSql(empresa, autobus);
		
				System.out.println(sql);
		
				SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy hh:mm:ss");
				NamedParameterStatement stmt = new NamedParameterStatement(conexao, sql);
				stmt.setTimestamp("fecInicio", new java.sql.Timestamp(sdf.parse(fecInicio).getTime()));
				stmt.setTimestamp("fecFinal", new java.sql.Timestamp(sdf.parse(fecFinal).getTime()));
				if (empresa != null && !empresa.equals("")){
					stmt.setInt("empresa_id", Integer.parseInt(empresa));
				}
				if (autobus != null && !autobus.equals("")){
					stmt.setInt("autobus_id", Integer.parseInt(autobus));
				}
				
				ResultSet rset = null;
		
				rset = stmt.executeQuery();
		
				lsDadosRelatorio = new ArrayList<RelatorioEmpresaOnibusBean>();
				
				while (rset.next()) {
					RelatorioEmpresaOnibusBean empresaOnibusBean = new RelatorioEmpresaOnibusBean();
					empresaOnibusBean.setCorridaId(rset.getInt("corridaId"));
					empresaOnibusBean.setEmpresa(rset.getString("empresa"));
					empresaOnibusBean.setCoche(Integer.parseInt(rset.getString("coche")));
					empresaOnibusBean.setDestino(rset.getString("destino"));
					empresaOnibusBean.setDia(rset.getDate("dia"));
					empresaOnibusBean.setHora(rset.getString("hora"));
					empresaOnibusBean.setKmts(rset.getInt("kmts"));
					empresaOnibusBean.setOrigem(rset.getString("origem"));
					
					lsDadosRelatorio.add(empresaOnibusBean);
				}
				
				if (lsDadosRelatorio.size() > 0) {
					setLsDadosRelatorio(lsDadosRelatorio);
				}
			}
		});
	}
	
	public void setLsDadosRelatorio(List<RelatorioEmpresaOnibusBean> lsDadosRelatorio) {
		this.setCollectionDataSource(new JRBeanCollectionDataSource(lsDadosRelatorio));
		this.lsDadosRelatorio = lsDadosRelatorio;
	}

	@Override
	protected void processaParametros() throws Exception {
	}
	
	private String getSql(String empresa, String autobus) {
		StringBuffer sql = new StringBuffer();

		sql.append(" select c.corrida_Id corridaId, e.nombempresa empresa, c.feccorrida dia, a.numautobus coche, ");
		sql.append("       o.cveparada origem, d.cveparada destino,  ");
		sql.append("       to_char(c.fechorsalida, 'HH24:MI') Hora, t.cantkmreal KMTS ");
		sql.append("       from corrida c ");
		sql.append("       left join ruta_combinacion rc on rc.ruta_id = c.ruta_id ");
		sql.append("       left join parada o on o.parada_id = c.origen_id ");
		sql.append("       left join parada d on d.parada_id = c.destino_id ");
		sql.append("       left join tramo t on t.origen_id = c.origen_id and t.destino_id = c.destino_id and t.tramo_id = rc.tramo_id  ");
		sql.append("       inner join autobus a on a.autobus_id = c.autobus_id ");
		sql.append("       left join empresa e on e.empresa_id = a.empresa_id ");
		sql.append("       where c.activo = 1  ");
		if (!empresa.isEmpty()){
			sql.append("       and e.empresa_id = :empresa_id  ");
		}
		if (!autobus.isEmpty()){
			sql.append("       and a.autobus_id = :autobus_id  ");
		}
		sql.append("       and rc.activo = 1 and c.feccorrida between :fecInicio and :fecFinal ");
		sql.append("       order by e.nombempresa, a.numautobus, c.feccorrida ");
		
		return sql.toString();
	}
}
